==> ws-v3.70.10-src.tar.gz: ws-v3.70-10/include/WSCvgraphScale.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSCVGRAPHSCALE_H
#define WSCVGRAPHSCALE_H

#include <WScom.h>
#include <WSCnwbase.h>
#define WSCvgraphScale_VER	1000

class WSCvgraphScale :public WSCnwbase{

  protected:
    char*     _values;
    char*     _barw;
    WSCushort _num;
    WSCuchar  _orientation;
    WSCuchar  _rev;
    WSCuchar  _lw;
    WSCuchar  _margin;
    unsigned  _lt:4;
    unsigned  _font:4;

    WSMFpropertyDef(WSNvalue,     char*,_values     );
    WSMFpropertyDef(WSNcolumns,   WSCushort,_num    );
    WSMFpropertyDef(WSNbarThickness,  char*,_barw );
    WSMFpropertyDef(WSNorientation,  WSCuchar,_orientation );
    WSMFpropertyDef(WSNreverseFlag,  WSCbool,_rev );
    WSMFpropertyDef(WSNlineWidth, WSCuchar, _lw);
    WSMFpropertyDef(WSNlineType,  WSCuchar,      _lt);
    WSMFpropertyDef(WSNmargin,  WSCuchar,      _margin);
    WSMFpropertyDef(WSNfont,         WSCuchar,   _font         );

  public:
    WSCvgraphScale(WSCbase* base, char* name);
    virtual ~WSCvgraphScale();

    virtual long draw();
    virtual char* getDefaultProperty();

    WSMFguiClassDef(WSCvgraphScale, WSCnwbase);
    WSMFversionDef  (WSCvgraphScale);
};
#endif

==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/include/WSCvgraphScale.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#ifndef WSCVGRAPHSCALE_H
#define WSCVGRAPHSCALE_H

#include <WScom.h>
#include <WSCnwbase.h>
#define WSCvgraphScale_VER	1000

class WSCvgraphScale :public WSCnwbase{

  protected:
    char*     _values;
    char*     _barw;
    WSCushort _num;
    WSCuchar  _orientation;
    WSCuchar  _rev;
    WSCuchar  _lw;
    WSCuchar  _margin;
    unsigned  _lt:4;
    unsigned  _font:4;

    WSMFpropertyDef(WSNvalue,     char*,_values     );
    WSMFpropertyDef(WSNcolumns,   WSCushort,_num    );
    WSMFpropertyDef(WSNbarThickness,  char*,_barw );
    WSMFpropertyDef(WSNorientation,  WSCuchar,_orientation );
    WSMFpropertyDef(WSNreverseFlag,  WSCbool,_rev );
    WSMFpropertyDef(WSNlineWidth, WSCuchar, _lw);
    WSMFpropertyDef(WSNlineType,  WSCuchar,      _lt);
    WSMFpropertyDef(WSNmargin,  WSCuchar,      _margin);
    WSMFpropertyDef(WSNfont,         WSCuchar,   _font         );

  public:
    WSDLEX32 WSCvgraphScale(WSCbase* base, char* name);
    WSDLEX32 virtual ~WSCvgraphScale();

    WSDLEX32 virtual long draw();
    WSDLEX32 virtual char* getDefaultProperty();

    WSMFguiClassDef(WSCvgraphScale, WSCnwbase);
    WSMFversionDef  (WSCvgraphScale);
};
#endif
